@@ -5,7 +5,7 @@ from optparse import Option, BadOptionError
 from rider.cli import cmdoptions
 from rider.cli.cmdparser import ConfigOptionParser, UpdatingDefaultsHelpFormatter
 from rider.cli.utils import get_prog
-from rider.pkg.fig.cli.log_printer import LogPrinter
+from rider.log import Logger
 from rider.environment import Environment
 
 
@@ -36,7 +36,7 @@ class Command(object):
         self.parser.add_option_group(gen_opts)
 
         # set logger
-        self.logger = LogPrinter()
+        self.logger = Logger()
 
 
     def setup_logging(self):
@@ -56,7 +56,6 @@ class Command(object):
         """
             The main interface for exectute the command
         """
-
         try:
             self.run(args)
         except Exception:
@@ -114,18 +113,53 @@ class ScaleCommand(Command):
 
 
 class CleanCommand(Command):
-    pass
+    name = "clean"
+    usage = """%prog """
+    summary = "build the new image"
+
+    def __init__(self):
+        super(Command, self).__init__()
 
 
 class BuildCommand(Command):
-    pass
+    name = "build"
+    usage = """%prog """
+    summary = "build the new image"
+
+    def __init__(self):
+        super(Command, self).__init__()
+        self.parser.add_option(Option(
+            '--splunk-pkg',
+            dest='splunk_pkg',
+            action='store',
+            default='splunk_tgz',
+            help="Splunk release build package"
+        ))
+
+        self.parser.add_option(Option(
+            '--image-name',
+            dest='image_name',
+            action='store',
+            default='10.66.128.203:49153/coreqa/splunk:latest',
+            help="Image Name"
+        ))
+
+    def run(self, args):
+        pass
 
 
-class InfoCommand(Command):
-    pass
+COMMANDS = {
+    BuildCommand.name: BuildCommand,
+    CleanCommand.name: CleanCommand,
+    ScaleCommand.name: ScaleCommand,
+}
 
 
-class ShowCommand(Command):
-    pass
-
+def get_summaries(ignore_hidden=True, ordered=True):
+    """Yields sorted (command name, command summary) tuples."""
+    cmd_items = COMMANDS.items()
+    for name, command_class in cmd_items:
+        if ignore_hidden and command_class.hidden:
+            continue
+        yield (name, command_class.summary)
 
