@@ -1,7 +1,7 @@
 import re
 
 from pkg.fig.project import Project
-from pkg.fig.service import VALID_NAME_CHARS,ConfigError,NAME_RE
+from pkg.fig.service import VALID_NAME_CHARS, ConfigError, NAME_RE
 from pkg.fig.cli.docker_client import docker_client
 
 from service import Service
@@ -27,17 +27,17 @@ class Environment(object):
     '''
     client = docker_client()
 
-    def __init__(self,env_name):
+    def __init__(self, env_name):
         self.env_name = env_name
 
     @classmethod
-    def create_environment(cls,env_type,env_name,image_name = DEFAULT_IMAGE):
+    def create_environment(cls, env_type, env_name, image_name=DEFAULT_IMAGE):
         if not re.match('^%s+$' % VALID_NAME_CHARS, env_name):
             raise ConfigError('Invalid service name "%s" - only %s are allowed' % (env_name, VALID_NAME_CHARS))
 
-        Env_class=ENV_CLASS_MAPPING[env_type]
-        new_env_name = "%s_%s" % (env_name,env_type)
-        return Env_class(new_env_name,image_name)
+        Env_class = ENV_CLASS_MAPPING[env_type]
+        new_env_name = "%s_%s" % (env_name, env_type)
+        return Env_class(new_env_name, image_name)
 
 
     @classmethod
@@ -50,33 +50,31 @@ class Environment(object):
                 env_instance = cls.get_environment_by_name(env_identifier, all_environment_name_image[env_identifier])
                 all_environment.append(env_instance)
 
-        return  all_environment
+        return all_environment
 
 
     @classmethod
-    def get_environment_by_name(cls,name,image):
-        env_name,env_type = name.split('_')
+    def get_environment_by_name(cls, name, image):
+        env_name, env_type = name.split('_')
 
-        Env_class=ENV_CLASS_MAPPING[env_type]
-        return Env_class(name,image)
+        Env_class = ENV_CLASS_MAPPING[env_type]
+        return Env_class(name, image)
 
         pass
 
 
     @classmethod
-    def get_all_environments_name_image_dict(cls,stopped=False):
+    def get_all_environments_name_image_dict(cls, stopped=False):
 
         all_environments_name_image = {}
         for container in cls.client.containers(all=stopped):
             match = NAME_RE.match(container['Names'][0])
             if match:
-                env_identifier =  match.group(1).replace("/","")+"_"+match.group(2)
+                env_identifier = match.group(1).replace("/", "") + "_" + match.group(2)
                 if not env_identifier in all_environments_name_image.keys():
                     all_environments_name_image[env_identifier] = container['Image']
 
         return all_environments_name_image
-        pass
-
 
 
     def get_service_names(self):
@@ -87,8 +85,6 @@ class Environment(object):
                 service_name.append(service.name)
 
         return service_name
-        pass
-
 
 
     def clean(self):
@@ -100,63 +96,81 @@ class Environment(object):
         pass
 
 
-    def _get_service_dict(self,image_name):
+    def _get_service_dict(self, image_name):
         pre_service_dict = ENV_DICT_MAPPING[ClusterEnvironment.env_type]
-        aft_service_dict =[]
+        aft_service_dict = []
         for service in pre_service_dict:
             service['image'] = image_name
             aft_service_dict.append(service)
-        return  aft_service_dict
+        return aft_service_dict
+
 
 class ClusterEnvironment(Environment):
-
     env_type = "cluster"
-    def __init__(self,env_name,image_name):
-        super(ClusterEnvironment,self).__init__(env_name)
+
+    def __init__(self, env_name, image_name):
+        super(ClusterEnvironment, self).__init__(env_name)
         # add your init functions
         self._image_name = image_name
         self._service_dict = self._get_service_dict(image_name)
-        self._project = Project.from_dicts(self.env_name,self._service_dict,self.client)
+        self._project = Project.from_dicts(self.env_name, self._service_dict, self.client)
         self._services = self._project.get_services()
         for service in self._services:
-            setattr(self,service.name, Service(service,self))
-
+            setattr(self, service.name, Service(service, self))
 
 
 class DistributedEnvironment(Environment):
-
     env_type = "dst"
-    def __init__(self,env_name):
-        super(DistributedEnvironment,self).__init__(env_name)
+
+    def __init__(self, env_name):
+        super(DistributedEnvironment, self).__init__(env_name)
+
 
 class ShcEnvironment(Environment):
     env_type = "shc"
-    def __init__(self,env_name):
-        super(ShcEnvironment,self).__init__(env_name)
-
 
+    def __init__(self, env_name):
+        super(ShcEnvironment, self).__init__(env_name)
 
 
 # CONSTANTS VARIABLES
 ENV_CLASS_MAPPING = {
-    ClusterEnvironment.env_type:ClusterEnvironment,
-    DistributedEnvironment.env_type:DistributedEnvironment,
-    ShcEnvironment.env_type:ShcEnvironment
+    ClusterEnvironment.env_type: ClusterEnvironment,
+    DistributedEnvironment.env_type: DistributedEnvironment,
+    ShcEnvironment.env_type: ShcEnvironment
 }
 
 ENV_DICT_MAPPING = {
-    ClusterEnvironment.env_type: [{'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'], 'links': ['master'], u'name': 'sh'}, {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'], u'name': 'master'}, {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'], 'links': ['master'], u'name': 'indexer'}],
-    DistributedEnvironment.env_type: [{'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'], 'links': ['master'], u'name': 'sh'}, {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'], u'name': 'master'}, {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'], 'links': ['master'], u'name': 'indexer'}],
-    ShcEnvironment.env_type:[{'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'], 'links': ['master'], u'name': 'sh'}, {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'], u'name': 'master'}, {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'], 'links': ['master'], u'name': 'indexer'}]
+    ClusterEnvironment.env_type: [
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
+         'links': ['master'], u'name': 'sh'},
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
+         u'name': 'master'},
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
+         'links': ['master'], u'name': 'indexer'}],
+    DistributedEnvironment.env_type: [
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
+         'links': ['master'], u'name': 'sh'},
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
+         u'name': 'master'},
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
+         'links': ['master'], u'name': 'indexer'}],
+    ShcEnvironment.env_type: [
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
+         'links': ['master'], u'name': 'sh'},
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
+         u'name': 'master'},
+        {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
+         'links': ['master'], u'name': 'indexer'}]
 }
 
 
 # if __name__ == "__main__":
 #
 #
-#     Environment.get_environments()
+# Environment.get_environments()
 #
-#     myEnv = Environment.create_environment("cluster","jacktestapi2")
+# myEnv = Environment.create_environment("cluster","jacktestapi2")
 #
 #     myEnv.get_service_names()
 #
